@@ -9,7 +9,7 @@ require DynaLoader;
 
 our @ISA = qw(DynaLoader);
 
-our $VERSION = '1.06';
+our $VERSION = '1.08';
 
 {
 no warnings;
@@ -251,8 +251,7 @@ None.
 
 =head1 AUTHOR
 
-Simon Cozens, C<simon@cpan.org>
-(Who else?)
+Joshua b. Jore C<jjore@cpan.org>
 
 =head1 SEE ALSO
 
